#
# spec file for package PTL
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 2
%define libname libptl%{sover}
Name:           PTL
Version:        2.3.3
Release:        1.15
Summary:        C++11 mutilthreading tasking system
License:        MIT
URL:            https://github.com/jrmadsen/PTL
Source:         https://github.com/jrmadsen/PTL/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  tbb-devel

%description
Parallel Tasking Library (PTL) is a C++11 multithreading tasking
system on top of std::thread featuring thread pools, task groups,
and lock-free task queues.

%package -n %{libname}
Summary:        Parallel Tasking Library

%description -n %{libname}
Parallel Tasking Library (PTL) is a C++11 multithreading tasking
system on top of std::thread featuring thread pools, task groups,
and lock-free task queues.

This package provides the shared library for %{name}.

%package -n ptl-devel
Summary:        Headers for building with PTL
Requires:       %{libname} = %{version}
Requires:       tbb-devel

%description -n ptl-devel
Parallel Tasking Library (PTL) is a C++11 multithreading tasking
system on top of std::thread featuring thread pools, task groups,
and lock-free task queues.

This package provides the headers and sources for developing against %{name}.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n ptl-devel
%license LICENSE
%doc README.md
%{_includedir}/PTL/
%{_libdir}/*.so
%{_libdir}/cmake/
%{_libdir}/pkgconfig/*.pc

%files -n %{libname}
%license LICENSE
%{_libdir}/*.so.*

%changelog
* Fri May 13 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.3.3:
  * Fixed message which did not honor verbosity level.
- Change from version 2.3.2:
  * Support for BUILD_OBJECT_LIBS.
* Sun Jan 16 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.3.1:
  * Threading: Fix GetNumberOfPhysicalCpus, it should never return
    zero [gh#jrmadsen/PTL#26].
* Sat Dec  4 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.3.0:
  * ThreadPool::Config [gh#jrmadsen/PTL#23].
  * Formatting updates [gh#jrmadsen/PTL#24].
* Fri Dec  3 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.1:
  * ThreadPool.h: fix typo by @stephanlachnit
    [gh#jrmadsen/PTL#20].
  * pkgconfig: Use Libs.private for "-pthread" flag by @badshah400
    [gh#jrmadsen/PTL#22].
- Drop PTL-incorrect-pthread-requires-in-pkgconfig.patch:
  incorporated upstream.
* Thu Dec  2 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.0:
  * New/improved support for initialization and finalization
    routines in ThreadPool.
- Changes from version 2.1.0:
  * Fix C++20 warnings from GCC 11.2.0.
  * Removed timemory.
  * Springclean CMake scripts and developer/client build/use
    interfaces.
- Changes from version 2.0.0:
  * Fixed memory leak issues in VUserTaskQueue.
  * removed VTaskGroup.
  * merged TaskGroup and TBBTaskGroup:
  - TBBTaskGroup is just an alias now.
  - TaskGroup will handle determine whether ThreadPool is TBB
    and submit tasks accordingly.
  * use tbb::task_arena in order to enable master/worker paradigm:
    full support for ThreadPool::execute_on_all_threads,
    ThreadPool::execute_on_specific_threads in TBB mode.
  * renamed many functions/fields to "main" instead of "master".
  * VTask no longer holds a pointer to task group: this was
    causing a data-race issue.
  * cmake option PTL_USE_LOCKS to enable mutex locking in
    scheduler instead of lock-free scheme.
  * removed unused numActThreads.
  * wait() member function for tasks.
- Add PTL-incorrect-pthread-requires-in-pkgconfig.patch to drop
  an incorrect Requires on pthread in the pkgconfig file that
  causes pkgconfig to automatically add unresolvable Requires to
  the %%{name}-devel rpm package [gh#jrmadsen/PTL#21].
- Update location of packaged cmake and pkgconfig files in keeping
  with upstream fixes.
* Sat Feb 13 2021 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of description; mention base thread library
  used.
* Sat Feb 13 2021 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
